// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"access-control-monitor/param/base"
)

// 登录接口
type LoginBody struct {
	Sn string `form:"sn" json:"sn" binding:"required"`
}

type LoginRequest struct {
	LoginBody
}

type LoginResp struct {
	Key string `json:"key"`
}

type LoginResponse struct {
	base.Result
	Data LoginResp `json:"data"`
}

// 人员上传接口
type RegisterBody struct {
	Sn string `form:"sn" json:"sn" binding:"required"`
	//AppKey       string `form:"app_key" json:"app_key" binding:"required"`
	WorkNo       string `form:"work_no" json:"work_no" binding:"required"`
	Name         string `form:"name" json:"name" binding:"required"`
	IdCert       string `form:"id_cert" json:"id_cert" binding:"required"`
	Gender       int    `form:"gender" json:"gender" binding:"required"`
	StaffType    int    `form:"staff_type" json:"staff_type" binding:"required"`
	Birthday     string `form:"birthday" json:"birthday" binding:"required"`
	Address      string `form:"address" json:"address" binding:"required"`
	IdIssue      string `form:"id_issue" json:"id_issue" binding:"required"`
	IdPeriod     string `form:"id_period" json:"id_period" binding:"required"`
	IdPhoto      string `form:"id_photo" json:"id_photo" binding:"required"`
	Photo        string `form:"photo" json:"photo" binding:"required"`
	InfPhoto     string `form:"inf_photo" json:"inf_photo" binding:"required"`
	Phone        string `form:"phone" json:"phone" binding:"required"`
	WorkType     int    `form:"work_type" json:"work_type" binding:"required"`
	LaborCompany string `form:"labor_company" json:"labor_company" binding:"required"`
	Group        string `form:"group" json:"group" binding:"required"`
}

type RegisterRequest struct {
	RegisterBody
}

type RegisterResponse struct {
	base.Result
}

// 删除员工信息
type StaffDeleteBody struct {
	Sn      string   `form:"sn" json:"sn" binding:"required"`
	WorkNos []string `form:"work_nos" json:"work_nos" binding:"required"`
	//AppKey string `json:"app_key" form:"app_key" binding:"required"`
}

type StaffDeleteRequest struct {
	StaffDeleteBody
}

type StaffDeleteResp struct {
	WorkNos []string `json:"work_nos"`
}

type StaffDeleteResponse struct {
	base.Result
	//Data StaffDeleteResp `json:"data"`
}

// 上传识别结果
type AttendanceContent struct {
	WorkNo    string `form:"work_no" json:"work_no" binding:"required"`
	RecogTime string `form:"recog_time" json:"recog_time" binding:"required"`
	IsIn      int    `form:"is_in" json:"is_in"  binding:"required"`
}

type AttendanceBody struct {
	Sn string `form:"sn" json:"sn" binding:"required"`
	// json 数组 Content 里面的内容用 des 加密 deskey: 对接的时候提供,
	// 加密前格式：
	//{
	//"count": 2,
	//"logs":[
	//{"sn": "XXXX","user_id": "XXXXX","recog_time":
	//"yyyy-Mm-dd HH:mm:SS"},
	//{"sn": "XXXX","user_id": "XXXXX","recog_time": "yyyy-M
	//m-dd HH:mm:SS"}
	//] }
	//AppKey  string              `form:"app_key" json:"app_key" binding:"required"`
	Content []AttendanceContent `form:"content" json:"content" binding:"required"`
}

type AttendanceRequest struct {
	AttendanceBody
}

type AttendanceResponse struct {
	base.Result
}

// 人员批量下发
type BatchDownload struct {
	Name   string `json:"name"`
	WorkNo string `json:"work_no"`
	IdCert string `json:"id_cert"`
	Photo  string `json:"photo"`
}

type BatchDownloadQuery struct {
	Sn string `json:"sn" form:"sn" binding:"required"`
	//AppKey string `json:"app_key" form:"app_key" binding:"required"`
}

type BatchDownloadRequet struct {
	BatchDownloadQuery
}

type BatchDownloadResponse struct {
	base.Result
	Data []BatchDownload `json:"data"`
}

// 反馈接口
type FeedBackBody struct {
	Sn string `form:"sn" json:"sn" binding:"required"`
	//AppKey string `form:"app_key" json:"app_key" binding:"required"`
	// 反馈类型:
	//0-人员删除成功，
	//1-人员删除失败，
	//2-人员下发成功，
	//3-人员下发失败
	Type int    `form:"type" json:"type" binding:"required"`
	Msg  string `form:"msg" json:"msg" binding:"required"`
}

type FeedBackRequet struct {
	FeedBackBody
}

type FeedBackResponse struct {
	// 返回类型: -3（反馈类型不能为空），-2（设备序
	//列号不存在）， -1（服务器异常-失败）， 0（空闲
	//-成功）
	base.Result
}

type PingRequest struct {
	PingBody
}

type PingBody struct {
	Sn string `form:"sn" json:"sn" binding:"required"`
}

type PingResponse struct {
	base.Result
}
